Crate pollfd

Crate pollfd 

Enums

Poll
Polling event types; see man poll(2)

Functions

poll
Polls a file descriptor for a maximum of timeout milliseconds. Returns when fd is available, when the timeout is reached, or on error.
pollfd